==> hs-utility-ht-0.0.7.tbz: lib/ghc-7.0.3/cabal/utility-ht-0.0.7/register.sh <==
#!/bin/sh
echo 'name: utility-ht
version: 0.0.7
id: utility-ht-0.0.7-fd5459ef2edccdf158ac71d82129755d

license: BSD3
copyright:
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
stability:
homepage:
package-url:
description: Various small helper functions for Lists, Maybes, Tuples, Functions.
             Some of these functions are improved implementations of standard functions.
             They have the same name as their standard counterparts.
             .
             All modules are plain Haskell 98.
             The package depends exclusively on the @base@ package
             and only that portions of @base@ that are simple to port.
             Thus you do not risk a dependency avalanche by importing it.
             However, further splitting the base package might invalidate this statement.
             .
             Alternative packages: @Useful@, @MissingH@
category: Data, List
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
exposed-modules: Data.Bool.HT Data.Eq.HT Data.Function.HT
                 Data.Ix.Enum Data.List.HT Data.List.Key Data.List.Match
                 Data.Maybe.HT Data.Monoid.HT Data.Ord.HT Data.Record.HT
                 Data.String.HT Data.Tuple.HT Control.Monad.HT Data.Strictness.HT
                 Text.Read.HT Text.Show.HT
hidden-modules: Data.Bool.HT.Private Data.List.HT.Private
                Data.List.Key.Private Data.List.Match.Private
                Data.Function.HT.Private Data.Record.HT.Private
import-dirs: /usr/local/lib/ghc-7.0.3/cabal/utility-ht-0.0.7
library-dirs: /usr/local/lib/ghc-7.0.3/cabal/utility-ht-0.0.7
              /usr/local/lib
hs-libraries: HSutility-ht-0.0.7
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.3/cabal/utility-ht-0.0.7/html/utility-ht.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.3/cabal/utility-ht-0.0.7/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"

==> hs-utility-ht-0.0.7.1.tbz: lib/ghc-7.0.4/cabal/utility-ht-0.0.7.1/register.sh <==
#!/bin/sh
echo 'name: utility-ht
version: 0.0.7.1
id: utility-ht-0.0.7.1-075c6b44efc10355784f1c74b49c577f

license: BSD3
copyright:
maintainer: Henning Thielemann <haskell@henning-thielemann.de>
stability:
homepage:
package-url:
description: Various small helper functions for Lists, Maybes, Tuples, Functions.
             Some of these functions are improved implementations of standard functions.
             They have the same name as their standard counterparts.
             .
             All modules are plain Haskell 98.
             The package depends exclusively on the @base@ package
             and only that portions of @base@ that are simple to port.
             Thus you do not risk a dependency avalanche by importing it.
             However, further splitting the base package might invalidate this statement.
             .
             Alternative packages: @Useful@, @MissingH@
category: Data, List
author: Henning Thielemann <haskell@henning-thielemann.de>
exposed: True
exposed-modules: Data.Bool.HT Data.Eq.HT Data.Function.HT
                 Data.Ix.Enum Data.List.HT Data.List.Key Data.List.Match
                 Data.Maybe.HT Data.Monoid.HT Data.Ord.HT Data.Record.HT
                 Data.String.HT Data.Tuple.HT Control.Monad.HT Data.Strictness.HT
                 Text.Read.HT Text.Show.HT
hidden-modules: Data.Bool.HT.Private Data.List.HT.Private
                Data.List.Key.Private Data.List.Match.Private
                Data.Function.HT.Private Data.Record.HT.Private
import-dirs: /usr/local/lib/ghc-7.0.4/cabal/utility-ht-0.0.7.1
library-dirs: /usr/local/lib/ghc-7.0.4/cabal/utility-ht-0.0.7.1
              /usr/local/lib
hs-libraries: HSutility-ht-0.0.7.1
extra-libraries:
extra-ghci-libraries:
include-dirs: /usr/local/include
includes:
depends: base-4.3.1.0-93a63ba911a7eac625848432374f7fee
hugs-options:
cc-options:
ld-options:
framework-dirs:
frameworks:
haddock-interfaces: /usr/local/share/doc/ghc-7.0.4/cabal/utility-ht-0.0.7.1/html/utility-ht.haddock
haddock-html: /usr/local/share/doc/ghc-7.0.4/cabal/utility-ht-0.0.7.1/html
' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
